# How to release

## Prepare the new release
1. Create a new branch for the release
2. Update the package version in `pyproject.toml`
3. Commit and push the changes
4. Run `task publish` to build and publish to PyPI
